@@ -1,4 +1,5 @@
 import asyncio
+from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
 from typing import Any
 from typing import Awaitable
 from typing import List
@@ -35,7 +36,7 @@ class AsyncFlowExecutor:
     @staticmethod
     async def _execute_one_flow(flow: AsyncFlow) -> Any:
         """Run"""
-        return await SingleFlowExecutor(flow).execute_flow()
+        return await SingleFlowExecutor(flow).execute_flow(is_root=True)
 
     def _execute_or_gather(self, flow: FlowOrListFlow) -> Awaitable[Any]:
         if isinstance(flow, list):
@@ -55,6 +56,12 @@ class AsyncFlowExecutor:
     def process_runner(self, **kwargs):
         return AsyncRunner(self.run, ExecutorType.PROCESS_POOL, **kwargs)
 
+    def with_thread_runner(self, thread_pool: ThreadPoolExecutor, **kwargs):
+        return AsyncRunner(self.run, thread_pool, **kwargs)
+
+    def with_process_runner(self, process_pool: ProcessPoolExecutor, **kwargs):
+        return AsyncRunner(self.run, process_pool, **kwargs)
+
     @staticmethod
     def ensure_flow(fn: Any, arg: Any = None) -> AsyncFlow:
         if isinstance(fn, AsyncFlow):
@@ -76,9 +83,7 @@ class AsyncFlowExecutor:
     def starmap(*flows: Any) -> AnyCallable:
         async def wrapper(arg: Any) -> Any:
             new_flows = [AsyncFlowExecutor.ensure_flow(fn, arg) for fn in flows]
-            result = (
-                await AsyncFlowExecutor().from_flows(new_flows).run()
-            )
+            result = await AsyncFlowExecutor().from_flows(new_flows).run()
             return result[0]
 
         return wrapper
